==> ejc-jlprogress-impl-3.0.0-20240615.061156-158-sources.jar: com/ejianc/business/jlprogress/quality/bean/PurchaseFeedbackEntity.java <==
package com.ejianc.business.jlprogress.quality.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 质量检测-进货质量反馈单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_quality_purchase_feedback")
public class PurchaseFeedbackEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码（质量反馈号）
    @TableField(value="supply_id")
    private Long supplyId; // 供货单号
    @TableField(value="supply_code")
    private String supplyCode; // 供货code
    @TableField(value="check_record_id")
    private Long checkRecordId; // 检验记录id
    @TableField(value="check_record_code")
    private String checkRecordCode; // 检验记录code
    @TableField(value="check_report_id")
    private Long checkReportId; // 检验报告id
    @TableField(value="check_report_code")
    private String checkReportCode; // 检验报告code
    @TableField(value="plan_id")
    private Long planId; // 计划单id
    @TableField(value="plan_name")
    private String planName; // 计划单code
    @TableField(value="plan_code")
    private String planCode; // 计划单name
    @TableField(value="employee_id")
    private Long employeeId; // 检验员
    @TableField(value="employee_name")
    private String employeeName; // 检验员名称
    @TableField(value="department_id")
    private Long departmentId; // 检验部门
    @TableField(value="department_name")
    private String departmentName; // 检验部门名称
    @TableField(value="custom_name")
    private String customName; // 客户名
    @TableField(value="supply_purchase_name")
    private String supplyPurchaseName; // 供货单采购员
    @TableField(value="problem_product_amount")
    private BigDecimal problemProductAmount; // 有问题产品数量
    @TableField(value="batch_product_amount")
    private BigDecimal batchProductAmount; // 本批产品数量
    @TableField(value="feedback_date")
    private Date feedbackDate; // 反馈日期
    @TableField(value="technical")
    private Integer technical; // 技术设计：0、让步接收，1、返工，2、维修，3、报废，4、退货
    @TableField(value="product")
    private Integer product; // 生产部门：0、让步接收，1、返工，2、维修，3、报废，4、退货
    @TableField(value="technical_manager")
    private Integer technicalManager; // 技术主管：0、让步接收，1、返工，2、维修，3、报废，4、退货
    @TableField(value="memo")
    private String memo; // 问题描述
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getSupplyId() {
        return supplyId;
    }

    public void setSupplyId(Long supplyId) {
        this.supplyId = supplyId;
    }
    public String getSupplyCode() {
        return supplyCode;
    }

    public void setSupplyCode(String supplyCode) {
        this.supplyCode = supplyCode;
    }
    public Long getCheckRecordId() {
        return checkRecordId;
    }

    public void setCheckRecordId(Long checkRecordId) {
        this.checkRecordId = checkRecordId;
    }
    public String getCheckRecordCode() {
        return checkRecordCode;
    }

    public void setCheckRecordCode(String checkRecordCode) {
        this.checkRecordCode = checkRecordCode;
    }
    public Long getCheckReportId() {
        return checkReportId;
    }

    public void setCheckReportId(Long checkReportId) {
        this.checkReportId = checkReportId;
    }
    public String getCheckReportCode() {
        return checkReportCode;
    }

    public void setCheckReportCode(String checkReportCode) {
        this.checkReportCode = checkReportCode;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public String getPlanCode() {
        return planCode;
    }

    public void setPlanCode(String planCode) {
        this.planCode = planCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }
    public String getSupplyPurchaseName() {
        return supplyPurchaseName;
    }

    public void setSupplyPurchaseName(String supplyPurchaseName) {
        this.supplyPurchaseName = supplyPurchaseName;
    }
    public BigDecimal getProblemProductAmount() {
        return problemProductAmount;
    }

    public void setProblemProductAmount(BigDecimal problemProductAmount) {
        this.problemProductAmount = problemProductAmount;
    }
    public BigDecimal getBatchProductAmount() {
        return batchProductAmount;
    }

    public void setBatchProductAmount(BigDecimal batchProductAmount) {
        this.batchProductAmount = batchProductAmount;
    }
    public Date getFeedbackDate() {
        return feedbackDate;
    }

    public void setFeedbackDate(Date feedbackDate) {
        this.feedbackDate = feedbackDate;
    }
    public Integer getTechnical() {
        return technical;
    }

    public void setTechnical(Integer technical) {
        this.technical = technical;
    }
    public Integer getProduct() {
        return product;
    }

    public void setProduct(Integer product) {
        this.product = product;
    }
    public Integer getTechnicalManager() {
        return technicalManager;
    }

    public void setTechnicalManager(Integer technicalManager) {
        this.technicalManager = technicalManager;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-jlprogress-impl-3.0.0-20241127.013018-459-sources.jar: com/ejianc/business/jlprogress/quality/bean/PurchaseFeedbackEntity.java <==
package com.ejianc.business.jlprogress.quality.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 质量检测-进货质量反馈单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_quality_purchase_feedback")
public class PurchaseFeedbackEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码（质量反馈号）
    @TableField(value="supply_id")
    private Long supplyId; // 供货单号
    @TableField(value="supply_code")
    private String supplyCode; // 供货code
    @TableField(value="check_record_id")
    private Long checkRecordId; // 检验记录id
    @TableField(value="check_record_code")
    private String checkRecordCode; // 检验记录code
    @TableField(value="check_report_id")
    private Long checkReportId; // 检验报告id
    @TableField(value="check_report_code")
    private String checkReportCode; // 检验报告code
    @TableField(value="plan_id")
    private Long planId; // 计划单id
    @TableField(value="plan_name")
    private String planName; // 计划单code
    @TableField(value="plan_code")
    private String planCode; // 计划单name
    @TableField(value="employee_id")
    private Long employeeId; // 检验员
    @TableField(value="employee_name")
    private String employeeName; // 检验员名称
    @TableField(value="department_id")
    private Long departmentId; // 检验部门
    @TableField(value="department_name")
    private String departmentName; // 检验部门名称
    @TableField(value="custom_name")
    private String customName; // 客户名
    @TableField(value="supply_purchase_name")
    private String supplyPurchaseName; // 供货单采购员
    @TableField(value="problem_product_amount")
    private BigDecimal problemProductAmount; // 有问题产品数量
    @TableField(value="batch_product_amount")
    private BigDecimal batchProductAmount; // 本批产品数量
    @TableField(value="feedback_date")
    private Date feedbackDate; // 反馈日期
    @TableField(value="technical")
    private Integer technical; // 技术设计：0、让步接收，1、返工，2、维修，3、报废，4、退货
    @TableField(value="product")
    private Integer product; // 生产部门：0、让步接收，1、返工，2、维修，3、报废，4、退货
    @TableField(value="technical_manager")
    private Integer technicalManager; // 技术主管：0、让步接收，1、返工，2、维修，3、报废，4、退货
    @TableField(value="loss_mny")
    private BigDecimal lossMny; // 损失金额
    @TableField(value="memo")
    private String memo; // 问题描述
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getSupplyId() {
        return supplyId;
    }

    public void setSupplyId(Long supplyId) {
        this.supplyId = supplyId;
    }
    public String getSupplyCode() {
        return supplyCode;
    }

    public void setSupplyCode(String supplyCode) {
        this.supplyCode = supplyCode;
    }
    public Long getCheckRecordId() {
        return checkRecordId;
    }

    public void setCheckRecordId(Long checkRecordId) {
        this.checkRecordId = checkRecordId;
    }
    public String getCheckRecordCode() {
        return checkRecordCode;
    }

    public void setCheckRecordCode(String checkRecordCode) {
        this.checkRecordCode = checkRecordCode;
    }
    public Long getCheckReportId() {
        return checkReportId;
    }

    public void setCheckReportId(Long checkReportId) {
        this.checkReportId = checkReportId;
    }
    public String getCheckReportCode() {
        return checkReportCode;
    }

    public void setCheckReportCode(String checkReportCode) {
        this.checkReportCode = checkReportCode;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public String getPlanCode() {
        return planCode;
    }

    public void setPlanCode(String planCode) {
        this.planCode = planCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getCustomName() {
        return customName;
    }

    public void setCustomName(String customName) {
        this.customName = customName;
    }
    public String getSupplyPurchaseName() {
        return supplyPurchaseName;
    }

    public void setSupplyPurchaseName(String supplyPurchaseName) {
        this.supplyPurchaseName = supplyPurchaseName;
    }
    public BigDecimal getProblemProductAmount() {
        return problemProductAmount;
    }

    public void setProblemProductAmount(BigDecimal problemProductAmount) {
        this.problemProductAmount = problemProductAmount;
    }
    public BigDecimal getBatchProductAmount() {
        return batchProductAmount;
    }

    public void setBatchProductAmount(BigDecimal batchProductAmount) {
        this.batchProductAmount = batchProductAmount;
    }
    public Date getFeedbackDate() {
        return feedbackDate;
    }

    public void setFeedbackDate(Date feedbackDate) {
        this.feedbackDate = feedbackDate;
    }
    public Integer getTechnical() {
        return technical;
    }

    public void setTechnical(Integer technical) {
        this.technical = technical;
    }
    public Integer getProduct() {
        return product;
    }

    public void setProduct(Integer product) {
        this.product = product;
    }
    public Integer getTechnicalManager() {
        return technicalManager;
    }

    public void setTechnicalManager(Integer technicalManager) {
        this.technicalManager = technicalManager;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public BigDecimal getLossMny() {
        return lossMny;
    }

    public void setLossMny(BigDecimal lossMny) {
        this.lossMny = lossMny;
    }
}
